# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['shylock', 'shylock.aio', 'shylock.backends', 'shylock.backends.tests']

package_data = \
{'': ['*']}

extras_require = \
{'aioarangodb': ['aioarangodb>=0.1.2,<0.2.0'],
 'motor': ['motor>=3.0.0,<4.0.0'],
 'pymongo': ['pymongo>=4.1,<5.0'],
 'python-arango': ['python-arango>=5.4.0,<6.0.0']}

setup_kwargs = {
    'name': 'shylock',
    'version': '1.2.1',
    'description': 'Distributed locks in Python, similar to https://github.com/vaidik/sherlock - also with asyncio support',
    'long_description': '.. image:: https://app.fossa.io/api/projects/git%2Bgithub.com%2Flietu%2Fshylock.svg?type=shield\n    :target: https://app.fossa.io/projects/git%2Bgithub.com%2Flietu%2Fshylock?ref=badge_shield\n\n.. image:: https://img.shields.io/github/actions/workflow/status/lietu/shylock/publish.yaml\n    :target: https://github.com/lietu/shylock/actions/workflows/publish.yaml\n\n.. image:: https://img.shields.io/badge/code%20style-black-000000.svg\n    :target: https://github.com/psf/black\n\n.. image:: https://codecov.io/gh/lietu/shylock/branch/master/graph/badge.svg\n    :target: https://codecov.io/gh/lietu/shylock\n\n.. image:: https://sonarcloud.io/api/project_badges/measure?project=lietu_shylock&metric=alert_status\n    :target: https://sonarcloud.io/dashboard?id=lietu_shylock\n\n.. image:: https://img.shields.io/github/issues/lietu/shylock\n    :target: https://github.com/lietu/shylock/issues\n    :alt: GitHub issues\n\n.. image:: https://img.shields.io/pypi/dm/shylock\n    :target: https://pypi.org/project/shylock/\n    :alt: PyPI - Downloads\n\n.. image:: https://img.shields.io/pypi/v/shylock\n    :target: https://pypi.org/project/shylock/\n    :alt: PyPI\n\n.. image:: https://img.shields.io/pypi/pyversions/shylock\n    :target: https://pypi.org/project/shylock/\n    :alt: PyPI - Python Version\n\n.. image:: https://img.shields.io/badge/License-BSD%203--Clause-blue.svg\n    :target: https://opensource.org/licenses/BSD-3-Clause\n\nDistributed locks on Python, with asyncio support\n\n\nWhat is this?\n=============\n\nLocks are required when you have a distributed system (like any API) and you want to ensure consistency for your data and prevent race conditions. There are a lot of ways to implement them, and this library aims to provide easy access to some of the better ways.\n\nThe library is written primarily for use with asyncio code, but also supports normal synchronous usage.\n\nCurrently supported backends:\n\n- MongoDB (using unique indexes + ttl indexes for consistency and safety)\n- ArangoDB (using unique indexes + ttl indexes for consistency and safety)\n\nCan be extended for other storage systems pretty easily.\n\nLicense\n-------\n\nLicensing is important. This project itself uses BSD 3-clause license, but e.g. Mongodb Motor library and other such libraries used by it may have their own licenses.\n\nFor more information check the `LICENSE <https://github.com/lietu/shylock/blob/master/LICENSE>`_ -file.\n\n\nGetting started\n===============\n\nAdd ``shylock`` to your project via pip / pipenv / poetry\n\n.. code-block:: bash\n\n    # MongoDB asyncio\n    pip install shylock[motor]\n    # MongoDB\n    pip install shylock[pymongo]\n    # ArangoDB asyncio\n    pip install shylock[aioarangodb]\n    # ArangoDB\n    pip install shylock[python-arango]\n\nFor most easy usage, you should in your application startup logic configure the default backend for Shylock to use, and then use the ``AsyncLock`` class to handle your locking needs.\n\n.. code-block:: python\n\n    from motor.motor_asyncio import AsyncIOMotorClient\n\n    from shylock import configure, AsyncLock as Lock, ShylockMotorAsyncIOBackend\n\n    CONNECTION_STRING = "mongodb://your-connection-string"\n\n    client = AsyncIOMotorClient(CONNECTION_STRING)\n    configure(await ShylockMotorAsyncIOBackend.create(client, "projectdb"))\n\n    async def use_lock():\n        async with Lock("my-lock"):\n            # The lock is now acquired, and will be automatically released\n            do_something()\n\n    async def another_lock_use():\n        lock = Lock("my-lock")\n        try:\n            await lock.acquire()\n            do_something()\n        finally:\n             await lock.release()\n\n    async def time_sensitive_code():\n        lock = Lock("my-lock")\n        try:\n            locked = await lock.acquire(block=False)\n            if locked:\n                do_something()\n        finally:\n             if locked:\n                 await lock.release()\n\nOr the ``Lock`` class for code where ``asyncio`` support isn\'t required\n\n.. code-block:: python\n\n    from pymongo import MongoClient\n\n    from shylock import configure, Lock, ShylockPymongoBackend\n\n    CONNECTION_STRING = "mongodb://your-connection-string"\n\n    client = MongoClient(CONNECTION_STRING)\n    configure(ShylockPymongoBackend.create(client, "projectdb"))\n\n    def use_lock():\n        with Lock("my-lock"):\n            # The lock is now acquired, and will be automatically released\n            do_something()\n\n    def another_lock_use():\n        lock = Lock("my-lock")\n        try:\n            lock.acquire()\n            do_something()\n        finally:\n             lock.release()\n\n    def time_sensitive_code():\n        lock = Lock("my-lock")\n        try:\n            locked = lock.acquire(block=False)\n            if locked:\n                do_something()\n        finally:\n             if locked:\n                 lock.release()\n\nYou can also check out the `examples <https://github.com/lietu/shylock/tree/master/examples/>`_, which also show how to use Shylock with ArangoDB.\n\n\nContributing\n============\n\nThis project is run on GitHub using the issue tracking and pull requests here. If you want to contribute, feel free to `submit issues <https://github.com/lietu/shylock/issues>`_ (incl. feature requests) or PRs here.\n\nTo test changes locally ``python setup.py develop`` is a good way to run this, and you can ``python setup.py develop --uninstall`` afterwards (you might want to also use the ``--user`` flag).\n\n.. image:: https://app.fossa.io/api/projects/git%2Bgithub.com%2Flietu%2Fshylock.svg?type=large\n    :target: https://app.fossa.io/projects/git%2Bgithub.com%2Flietu%2Fshylock?ref=badge_shield\n\n\nFinancial support\n=================\n\nThis project has been made possible thanks to `Cocreators <https://cocreators.ee>`_ and `Lietu <https://lietu.net>`_. You can help us continue our open source work by supporting us on `Buy me a coffee <https://www.buymeacoffee.com/cocreators>`_.\n\n.. image:: https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png\n   :target: https://www.buymeacoffee.com/cocreators\n',
    'author': 'Janne Enberg',
    'author_email': 'janne.enberg@lietu.net',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/lietu/shylock/',
    'packages': packages,
    'package_data': package_data,
    'extras_require': extras_require,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
